@@ -77,6 +77,30 @@ class MbstringTest extends TestCase
         $this->assertSame('déjà', mb_convert_encoding(utf8_decode('déjà'), 'Utf-8', ['ASCII', 'ISO-2022-JP', 'UTF-8', 'ISO-8859-1']));
     }
 
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_convert_encoding
+     *
+     * @requires PHP 7.2
+     */
+    public function testConvertEncodingWithArrayValue()
+    {
+        $this->assertSame(['déjà', 'là'], mb_convert_encoding(['d&eacute;j&#224;', 'l&#224;'], 'Utf-8', 'Html-entities'));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_convert_encoding
+     *
+     * @requires PHP < 7.2
+     */
+    public function testConvertEncodingWithArrayValueForPhpLessThan72()
+    {
+        $errorMessage = null;
+        set_error_handler(function ($type, $msg, $file, $line) use (&$errorMessage) { $errorMessage = \E_USER_WARNING === $type || \E_WARNING === $type ? $msg : null; });
+        $this->assertNull(mb_convert_encoding(['d&eacute;j&#224;', 'l&#224;'], 'Utf-8', 'Html-entities'));
+        restore_error_handler();
+        $this->assertSame('mb_convert_encoding() expects parameter 1 to be string, array given', $errorMessage);
+    }
+
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_decode_numericentity
      */
@@ -119,6 +143,7 @@ class MbstringTest extends TestCase
 
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_decode_numericentity
+     *
      * @requires PHP < 8
      */
     public function testDecodeNumericEntityWithInvalidTypes()
@@ -196,6 +221,7 @@ class MbstringTest extends TestCase
 
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_encode_numericentity
+     *
      * @requires PHP < 8
      */
     public function testEncodeNumericEntityWithInvalidTypes()
@@ -369,6 +395,7 @@ class MbstringTest extends TestCase
 
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_strpos
+     *
      * @requires PHP < 8
      */
     public function testStrposEmptyDelimiter()
@@ -490,11 +517,9 @@ class MbstringTest extends TestCase
 
         $this->assertFalse(mb_check_encoding(['aςσb' => 'aςσb', "\xE9" => 'abc'], 'UTF8'));
 
-
         $this->assertTrue(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc', 'aςσb']], 'UTF8'));
         $this->assertTrue(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc' => 'abc', 'aςσb' => 'aςσb']], 'UTF8'));
 
-
         $this->assertFalse(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc' => 'abc', 'aςσb' => "\xE9"]], 'UTF8'));
         $this->assertFalse(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc' => 'abc', "\xE9" => 'aςσb']], 'UTF8'));
     }
@@ -513,7 +538,6 @@ class MbstringTest extends TestCase
         $this->assertSame('mb_check_encoding() expects parameter 1 to be string, array given', $errorMessage);
     }
 
-
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_detect_encoding
      */
@@ -635,7 +659,7 @@ class MbstringTest extends TestCase
      * @dataProvider paddingEmojiProvider
      * @dataProvider paddingEncodingProvider
      */
-    public function testMbStrPad(string $expectedResult, string $string, int $length, string $padString, int $padType, string $encoding = null): void
+    public function testMbStrPad(string $expectedResult, string $string, int $length, string $padString, int $padType, ?string $encoding = null): void
     {
         if ('UTF-32' === $encoding && \PHP_VERSION_ID < 73000) {
             $this->markTestSkipped('PHP < 7.3 doesn\'t handle UTF-32 encoding properly');
@@ -649,7 +673,7 @@ class MbstringTest extends TestCase
      *
      * @dataProvider mbStrPadInvalidArgumentsProvider
      */
-    public function testMbStrPadInvalidArguments(string $expectedError, string $string, int $length, string $padString, int $padType, string $encoding = null): void
+    public function testMbStrPadInvalidArguments(string $expectedError, string $string, int $length, string $padString, int $padType, ?string $encoding = null): void
     {
         $this->expectException(\ValueError::class);
         $this->expectErrorMessage($expectedError);
@@ -657,6 +681,22 @@ class MbstringTest extends TestCase
         mb_str_pad($string, $length, $padString, $padType, $encoding);
     }
 
+    /**
+     * @dataProvider ucFirstDataProvider
+     */
+    public function testMbUcFirst(string $string, string $expected): void
+    {
+        $this->assertSame($expected, mb_ucfirst($string));
+    }
+
+    /**
+     * @dataProvider lcFirstDataProvider
+     */
+    public function testMbLcFirst(string $string, string $expected): void
+    {
+        $this->assertSame($expected, mb_lcfirst($string));
+    }
+
     public static function paddingStringProvider(): iterable
     {
         // Simple ASCII strings
@@ -727,4 +767,45 @@ class MbstringTest extends TestCase
         yield ['mb_str_pad(): Argument #4 ($pad_type) must be STR_PAD_LEFT, STR_PAD_RIGHT, or STR_PAD_BOTH', '▶▶', 6, ' ', 123456];
         yield ['mb_str_pad(): Argument #5 ($encoding) must be a valid encoding, "unexisting" given', '▶▶', 6, ' ', \STR_PAD_BOTH, 'unexisting'];
     }
+
+    public static function ucFirstDataProvider(): array
+    {
+        return [
+            ['', ''],
+            ['test', 'Test'],
+            ['TEST', 'TEST'],
+            ['TesT', 'TesT'],
+            ['ａｂ', 'Ａｂ'],
+            ['ＡＢＳ', 'ＡＢＳ'],
+            ['đắt quá!', 'Đắt quá!'],
+            ['აბგ', 'აბგ'],
+            ['ǉ', 'ǈ'],
+            ["\u{01CA}", "\u{01CB}"],
+            ["\u{01CA}\u{01CA}", "\u{01CB}\u{01CA}"],
+            ['łámał', 'Łámał'],
+            // Full case-mapping and case-folding that changes the length of the string only supported
+            // in PHP > 7.3.
+            ['ßst', \PHP_VERSION_ID < 70300 ? 'ßst' : 'Ssst'],
+        ];
+    }
+
+    public static function lcFirstDataProvider(): array
+    {
+        return [
+            ['', ''],
+            ['test', 'test'],
+            ['Test', 'test'],
+            ['tEST', 'tEST'],
+            ['Ａｂ', 'ａｂ'],
+            ['ＡＢＳ', 'ａＢＳ'],
+            ['Đắt quá!', 'đắt quá!'],
+            ['აბგ', 'აბგ'],
+            ['ǈ', \PHP_VERSION_ID < 70200 ? 'ǈ' : 'ǉ'],
+            ["\u{01CB}", \PHP_VERSION_ID < 70200 ? "\u{01CB}" : "\u{01CC}"],
+            ["\u{01CA}", "\u{01CC}"],
+            ["\u{01CA}\u{01CA}", "\u{01CC}\u{01CA}"],
+            ["\u{212A}\u{01CA}", "\u{006b}\u{01CA}"],
+            ['ß', 'ß'],
+        ];
+    }
 }
